@@ -73,6 +73,12 @@ class Scraper:
                 el = self.join(el, join)
 
         # step 3 apply dataTypes
+        tokens = dataType.split('[')
+        dataType = tokens[0]
+        format = dataType[1][:-1]
+
+        if dataType == WebScraper.Types.DATE:
+            el = Types.to_date(el, format=format)
         if dataType == WebScraper.Types.PERCENTAGE:
             el = Types.to_number(el.replace('%', ''))
         if dataType == WebScraper.Types.BOOL:
