@@ -52,7 +52,7 @@ class Selenium(Scraper):
         try:
             el = self.on_exists(element=element, path=path, timeout=timeout)
             if el != False:
-                return (self.driver if element is None else element).find_elements_by_xpath(path)
+                return (self.driver if element is None else element).find_elements(by=By.XPATH, value=path)
             else:
                 return None
         
@@ -73,7 +73,7 @@ class Selenium(Scraper):
                 return False
         else:
             try:
-                return element.find_element_by_xpath(path)
+                return element.find_elements(by=By.XPATH, value=path)
 
             except NoSuchElementException:
                 return False
@@ -148,13 +148,11 @@ class Selenium(Scraper):
     def on_get_scroll_bottom(self):
         return self.driver.execute_script('return document.body.scrollHeight')
 
-    def on_select(self, path, option, element=None):
+    def on_select(self, path: str, option: str, element: any=None) -> None:
         element = WebDriverWait(self.driver if element is None else element, 10).until(
             EC.presence_of_element_located((By.XPATH, path))
         )
 
-        option = self.on_xPath(element=element, path=option, prop='text()')
-
         if element is not None:
             Select(element).select_by_visible_text(option)
 
