@@ -39,4 +39,4 @@ class Service:
         self.repository.save(entity=entity)
 
     def wget(self, url: str, parameters: dict=None, method: Methods=Methods.GET) -> any:
-        return requests.get(url, data = parameters)
+        return requests.get(url=url, data=parameters).text
